webhooks

package
v1.15.0-alpha.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 1, 2025 License: Apache-2.0 Imports: 20 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CELExceptionHandlers added in v1.14.0

type CELExceptionHandlers struct {
	// Validation performs the validation check on cel exception resources
	Validation Handler
}

type DebugModeOptions added in v1.9.0

type DebugModeOptions struct {
	// DumpPayload is used to activate/deactivate debug mode.
	DumpPayload bool
}

DebugModeOptions holds the options to configure debug mode

type ExceptionHandlers added in v1.9.0

type ExceptionHandlers struct {
	// Validation performs the validation check on exception resources
	Validation Handler
}

type GlobalContextHandlers added in v1.12.0

type GlobalContextHandlers struct {
	// Validation performs the validation check on global context entries
	Validation Handler
}

type Handler added in v1.14.0

type HandlerFunc added in v1.14.0

func (HandlerFunc) Execute added in v1.14.0

func (f HandlerFunc) Execute(ctx context.Context, logger logr.Logger, request handlers.AdmissionRequest, failurePolicy string, startTime time.Time) admissionv1.AdmissionResponse

type PolicyHandlers added in v1.8.0

type PolicyHandlers struct {
	// Mutation performs the mutation of policy resources
	Mutation Handler
	// Validation performs the validation check on policy resources
	Validation Handler
}

type ResourceHandlers added in v1.8.0

type ResourceHandlers struct {
	// Mutation performs the mutation of kube resources
	Mutation Handler
	// Validation performs the validation check on kube resources
	Validation Handler
	// ValidatingPolicies evaluates validating policies against kube resources
	ValidatingPolicies Handler
	// ImageVerificationPolicies evaluates imageverificationpolicies mutation phase against kube resources
	ImageVerificationPoliciesMutation Handler
	// ImageVerificationPolicies evaluates imageverificationpolicies validation phase against kube resources
	ImageVerificationPolicies Handler
}

type Server added in v1.8.0

type Server interface {
	// Run TLS server in separate thread and returns control immediately
	Run()
	// Stop TLS server and returns control after the server is shut down
	Stop()
}

func NewServer added in v1.8.0

func NewServer(
	ctx context.Context,
	policyHandlers PolicyHandlers,
	resourceHandlers ResourceHandlers,
	exceptionHandlers ExceptionHandlers,
	celExceptionHandlers CELExceptionHandlers,
	globalContextHandlers GlobalContextHandlers,
	configuration config.Configuration,
	metricsConfig metrics.MetricsConfigManager,
	debugModeOpts DebugModeOptions,
	tlsProvider TlsProvider,
	mwcClient controllerutils.DeleteCollectionClient,
	vwcClient controllerutils.DeleteCollectionClient,
	leaseClient controllerutils.DeleteClient,
	runtime runtimeutils.Runtime,
	rbLister rbacv1listers.RoleBindingLister,
	crbLister rbacv1listers.ClusterRoleBindingLister,
	discovery dclient.IDiscovery,
	webhookServerPort int32,
) Server

NewServer creates new instance of server accordingly to given configuration

type TlsProvider added in v1.8.0

type TlsProvider func() ([]byte, []byte, error)

Jump to